ComplexCombination
==================

.. currentmodule:: pykeen.nn.combinations

.. autoclass:: ComplexCombination
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ComplexCombination.forward
      ~ComplexCombination.score_imag
      ~ComplexCombination.score_real

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: score_imag
   .. automethod:: score_real
